/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.converter;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.ViewScoped;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.FacesConverter;

import kieker.analysis.model.analysisMetaModel.MIPort;
import kieker.webgui.beans.view.CurrentAnalysisEditorBean;

/**
 * This converter can be used to convert a given port model instance to a string and vice versa (It uses the object's toString-method).
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ViewScoped
@ManagedBean
@FacesConverter(value = MIPortStringConverter.NAME)
public class MIPortStringConverter implements Converter {
	/**
	 * This is the name of this converter.
	 */
	public static final String NAME = "kieker.webgui.converter.MIPortStringConverter";

	@ManagedProperty(value = "#{currentAnalysisEditorBean}")
	private CurrentAnalysisEditorBean bean;

	/**
	 * Creates a new instance of this class.
	 */
	public MIPortStringConverter() {
		/* No code necessary. */
	}

	/**
	 * The getter for the {@link #bean}-property.
	 * 
	 * @return {@link #bean}
	 */
	public CurrentAnalysisEditorBean getBean() {
		return this.bean;
	}

	/**
	 * The setter for the {@link #bean}-property.
	 * 
	 * @param bean
	 *            The new value for {@link #bean}.
	 */
	public void setBean(final CurrentAnalysisEditorBean bean) {
		this.bean = bean;
	}

	@Override
	public Object getAsObject(final FacesContext fc, final UIComponent uic, final String string) {
		if (this.bean != null) {
			return this.bean.getPortByID(string);
		} else {
			return null;
		}
	}

	@Override
	public String getAsString(final FacesContext fc, final UIComponent uic, final Object o) {
		if ((o == null) || (this.bean == null)) {
			return "";
		} else {
			return Integer.toString(this.bean.getPortID((MIPort) o));
		}
	}
}
